import QtQuick 2.0
import QtQuick.Controls 2.12
import QtQuick.Layouts 1.12
import QtQuick.Dialogs 1.3
import Mjusik 1.0

ApplicationWindow
{
	width: 500
	height: 300
	visible: true

	FileDialog
	{
		id: fileDialog
		nameFilters: [ "*.gpx" ]
	}

	Binding
	{
		target: viewModel
		property: "fileUrl"
		value: fileDialog.fileUrl
	}

	WindowViewModel
	{
		id: viewModel
	}

	ColumnLayout
	{
		anchors
		{
			fill: parent
			margins: 10
		}

		spacing: 10

		RowLayout
		{
			Layout.fillWidth: true

			TextField
			{
				Layout.fillWidth: true

				placeholderText: "Filename"
				readOnly: true
				text: fileDialog.fileUrl
			}

			Button
			{
				Layout.maximumWidth: height

				enabled: !viewModel.playing

				icon
				{
					name: "document-open"
				}

				onClicked: fileDialog.open()
			}

			Button
			{
				width: height
				enabled: viewModel.canExecute

				icon
				{
					name: "run-build"
				}

				onClicked: viewModel.execute()
			}
		}

		Visualizer
		{
			Layout.fillWidth: true
			Layout.fillHeight: true

			id: visualizer
			data: viewModel.data
			progress: viewModel.progress
		}

		Rectangle
		{
			anchors
			{
				fill: visualizer
			}

			color: palette.midlight
			visible: viewModel.data === null

			Label
			{
				anchors
				{
					centerIn: parent
				}

				text: "Load a file"
			}
		}

		Button
		{
			icon
			{
				name: "media-playback-start"
			}

			enabled: !viewModel.playing

			onClicked: viewModel.play()
		}
	}
}
